This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] f: Follow spelling conventions.


Hi,

Attached is a patch to follow spelling conventions.  Committed as
obvious.

Kazu Hirata

2002-09-23  Kazu Hirata  <kazu@cs.umass.edu>

	* ChangeLog: Follow spelling conventions.
	* ChangeLog.0: Likewise.
	* com.c: Likewise.
	* ffe.texi: Likewise.
	* g77.texi: Likewise.
	* intdoc.in: Likewise.
	* invoke.texi: Likewise.
	* news.texi: Likewise.
	* intdoc.texi: Regenerate.

Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/ChangeLog,v
retrieving revision 1.494
diff -u -r1.494 ChangeLog
--- ChangeLog	16 Sep 2002 18:33:21 -0000	1.494
+++ ChangeLog	23 Sep 2002 10:32:30 -0000
@@ -3048,7 +3048,7 @@
 Sat Jul 11 18:24:37 1998  Craig Burley  <burley@gnu.org>
 
 	* com.c (ffecom_expr_) [FFEBLD_opCONTER]: Die if padding
-	for constant is non-zero.
+	for constant is nonzero.
 
 	* com.c (__eprintf): Delete this function, it is obsolete.
 
@@ -3104,7 +3104,7 @@
 	and even more elegantly than those.
 
 	* target.c (ffetarget_align): Make sure alignments
-	are non-zero, just in case.
+	are nonzero, just in case.
 
 See ChangeLog.0 for earlier changes.
 
Index: ChangeLog.0
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/ChangeLog.0,v
retrieving revision 1.2
diff -u -r1.2 ChangeLog.0
--- ChangeLog.0	4 Sep 1999 15:09:00 -0000	1.2
+++ ChangeLog.0	23 Sep 2002 10:32:35 -0000
@@ -38,7 +38,7 @@
 	of equiv area, extend lowering to maintain needed alignment.
 	* target.c (ffetarget_align): Handle negative offset correctly.
 
-	* global.c (ffeglobal_pad_common): Warn about non-zero
+	* global.c (ffeglobal_pad_common): Warn about nonzero
 	padding only the first time its seen.
 	If new padding larger than old, update old.
 	(ffeglobal_save_common): Use correct type for size throughout.
@@ -2419,7 +2419,7 @@
 	function call to the type in the fall-through case).
 
 	* ste.c (ffeste_R909_finish): Don't special-case list-directed
-	I/O, now that libf2c can return non-zero status codes.
+	I/O, now that libf2c can return nonzero status codes.
 	(ffeste_R910_finish): Ditto.
 	(ffeste_io_call_): Simplify logic.
 	(ffeste_io_impdo_):
Index: ffe.texi
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/ffe.texi,v
retrieving revision 1.13
diff -u -r1.13 ffe.texi
--- ffe.texi	9 Sep 2002 20:37:09 -0000	1.13
+++ ffe.texi	23 Sep 2002 10:32:50 -0000
@@ -2028,7 +2028,7 @@
 A generic integer of type @code{int}.
 
 @item is
-A generic integer that contains a true (non-zero) or false (zero) value.
+A generic integer that contains a true (nonzero) or false (zero) value.
 
 @item len
 A generic integer that contains the length of something.
Index: g77.texi
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/g77.texi,v
retrieving revision 1.94
diff -u -r1.94 g77.texi
--- g77.texi	6 Aug 2002 14:00:43 -0000	1.94
+++ g77.texi	23 Sep 2002 10:33:02 -0000
@@ -6283,7 +6283,7 @@
 is preserved.
 
 Debuggers that understand Fortran should have no trouble with
-non-zero low bounds, but for non-Fortran debuggers, especially
+nonzero low bounds, but for non-Fortran debuggers, especially
 C debuggers, the above example might have a C equivalent of
 @samp{a[4305]}.
 This calculation is arrived at by eliminating the subtraction
@@ -8547,7 +8547,7 @@
 that your program is linked against the correct version of the C library.
 The configuration process takes care to account for your
 system's normal @file{libc} not being ANSI-standard, which will
-otherwise cause this behaviour.
+otherwise cause this behavior.
 If your system's default library is
 ANSI-standard and you subsequently link against a non-ANSI one, there
 might be problems such as this one.
@@ -9460,9 +9460,9 @@
 ignored.
 (Ignoring them typically results in NaN values being
 propagated in systems that conform to IEEE 754.)
-The behaviour is normally inherited from the system-dependent startup
+The behavior is normally inherited from the system-dependent startup
 code, though some targets, such as the Alpha, have code generation
-options which change the behaviour.
+options which change the behavior.
 
 Most systems provide some C-callable mechanism to change this; this can
 be invoked at startup using @command{gcc}'s @code{constructor} attribute.
Index: intdoc.in
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/intdoc.in,v
retrieving revision 1.23
diff -u -r1.23 intdoc.in
--- intdoc.in	15 Sep 2002 21:40:40 -0000	1.23
+++ intdoc.in	23 Sep 2002 10:33:04 -0000
@@ -1617,7 +1617,7 @@
 DEFDOC (CHDIR_subr, "Change directory.", "\
 Sets the current working directory to be @var{@1@}.
 If the @var{@2@} argument is supplied, it contains 0
-on success or a non-zero error code otherwise upon return.
+on success or a nonzero error code otherwise upon return.
 See @code{chdir(3)}.
 
 @emph{Caution:} Using this routine during I/O to a unit connected with a
@@ -1631,7 +1631,7 @@
 
 DEFDOC (CHDIR_func, "Change directory.", "\
 Sets the current working directory to be @var{@1@}.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 See @code{chdir(3)}.
 
 @emph{Caution:} Using this routine during I/O to a unit connected with a
@@ -1652,7 +1652,7 @@
 Currently, @var{@1@} must not contain the single quote
 character.
 
-Returns 0 on success or a non-zero error code otherwise.
+Returns 0 on success or a nonzero error code otherwise.
 
 Note that this currently works
 by actually invoking @code{/bin/chmod} (or the @code{chmod} found when
@@ -1674,7 +1674,7 @@
 character.
 
 If the @var{@3@} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 
 Note that this currently works
 by actually invoking @code{/bin/chmod} (or the @code{chmod} found when
@@ -1689,7 +1689,7 @@
 DEFDOC (GETCWD_func, "Get current working directory.", "\
 Places the current working directory in @var{@1@}.
 Returns 0 on
-success, otherwise a non-zero error code
+success, otherwise a nonzero error code
 (@code{ENOSYS} if the system does not provide @code{getcwd(3)}
 or @code{getwd(3)}).
 ")
@@ -1697,7 +1697,7 @@
 DEFDOC (GETCWD_subr, "Get current working directory.", "\
 Places the current working directory in @var{@1@}.
 If the @var{@2@} argument is supplied, it contains 0
-success or a non-zero error code upon return
+success or a nonzero error code upon return
 (@code{ENOSYS} if the system does not provide @code{getcwd(3)}
 or @code{getwd(3)}).
 
@@ -1758,7 +1758,7 @@
 Not all these elements are relevant on all systems.
 If an element is not relevant, it is returned as 0.
 
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 ")
 
 DEFDOC (FSTAT_subr, "Get file information.", "\
@@ -1814,7 +1814,7 @@
 If an element is not relevant, it is returned as 0.
 
 If the @var{@3@} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
 only a function, not as a subroutine, or do not support the
@@ -1878,7 +1878,7 @@
 Not all these elements are relevant on all systems.
 If an element is not relevant, it is returned as 0.
 
-Returns 0 on success or a non-zero error code
+Returns 0 on success or a nonzero error code
 (@code{ENOSYS} if the system does not provide @code{lstat(2)}).
 ")
 
@@ -1940,7 +1940,7 @@
 If an element is not relevant, it is returned as 0.
 
 If the @var{@3@} argument is supplied, it contains
-0 on success or a non-zero error code upon return
+0 on success or a nonzero error code upon return
 (@code{ENOSYS} if the system does not provide @code{lstat(2)}).
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -2002,7 +2002,7 @@
 Not all these elements are relevant on all systems.
 If an element is not relevant, it is returned as 0.
 
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 ")
 
 DEFDOC (STAT_subr, "Get file information.", "\
@@ -2060,7 +2060,7 @@
 If an element is not relevant, it is returned as 0.
 
 If the @var{@3@} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
 only a function, not as a subroutine, or do not support the
@@ -2073,7 +2073,7 @@
 the names in @var{@1@} and @var{@2@}---otherwise,
 trailing blanks in @var{@1@} and @var{@2@} are ignored.
 If the @var{@3@} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 See @code{link(2)}.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -2086,7 +2086,7 @@
 A null character (@samp{CHAR(0)}) marks the end of
 the names in @var{@1@} and @var{@2@}---otherwise,
 trailing blanks in @var{@1@} and @var{@2@} are ignored.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 See @code{link(2)}.
 
 Due to the side effects performed by this intrinsic, the function
@@ -2099,7 +2099,7 @@
 the names in @var{@1@} and @var{@2@}---otherwise,
 trailing blanks in @var{@1@} and @var{@2@} are ignored.
 If the @var{@3@} argument is supplied, it contains
-0 on success or a non-zero error code upon return
+0 on success or a nonzero error code upon return
 (@code{ENOSYS} if the system does not provide @code{symlink(2)}).
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -2112,7 +2112,7 @@
 A null character (@samp{CHAR(0)}) marks the end of
 the names in @var{@1@} and @var{@2@}---otherwise,
 trailing blanks in @var{@1@} and @var{@2@} are ignored.
-Returns 0 on success or a non-zero error code
+Returns 0 on success or a nonzero error code
 (@code{ENOSYS} if the system does not provide @code{symlink(2)}).
 
 Due to the side effects performed by this intrinsic, the function
@@ -2126,7 +2126,7 @@
 trailing blanks in @var{@1@} and @var{@2@} are ignored.
 See @code{rename(2)}.
 If the @var{@3@} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
 only a function, not as a subroutine, or do not support the
@@ -2139,7 +2139,7 @@
 the names in @var{@1@} and @var{@2@}---otherwise,
 trailing blanks in @var{@1@} and @var{@2@} are ignored.
 See @code{rename(2)}.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 
 Due to the side effects performed by this intrinsic, the function
 form is not recommended.
@@ -2168,7 +2168,7 @@
 the name in @var{@1@}---otherwise,
 trailing blanks in @var{@1@} are ignored.
 If the @var{@2@} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 See @code{unlink(2)}.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -2181,7 +2181,7 @@
 A null character (@samp{CHAR(0)}) marks the end of
 the name in @var{@1@}---otherwise,
 trailing blanks in @var{@1@} are ignored.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 See @code{unlink(2)}.
 
 Due to the side effects performed by this intrinsic, the function
@@ -2238,7 +2238,7 @@
 
 DEFDOC (HOSTNM_func, "Get host name.", "\
 Fills @var{@1@} with the system's host name returned by
-@code{gethostname(2)}, returning 0 on success or a non-zero error code
+@code{gethostname(2)}, returning 0 on success or a nonzero error code
 (@code{ENOSYS} if the system does not provide @code{gethostname(2)}).
 
 On some systems (specifically SCO) it might be necessary to link the
@@ -2251,7 +2251,7 @@
 Fills @var{@1@} with the system's host name returned by
 @code{gethostname(2)}.
 If the @var{@2@} argument is supplied, it contains
-0 on success or a non-zero error code upon return
+0 on success or a nonzero error code upon return
 (@code{ENOSYS} if the system does not provide @code{gethostname(2)}).
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -2513,7 +2513,7 @@
 
 DEFDOC (KILL_func, "Signal a process.", "\
 Sends the signal specified by @var{@2@} to the process @var{@1@}.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 See @code{kill(2)}.
 
 Due to the side effects performed by this intrinsic, the function
@@ -2523,7 +2523,7 @@
 DEFDOC (KILL_subr, "Signal a process.", "\
 Sends the signal specified by @var{@2@} to the process @var{@1@}.
 If the @var{@3@} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 See @code{kill(2)}.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
Index: intdoc.texi
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/intdoc.texi,v
retrieving revision 1.22
diff -u -r1.22 intdoc.texi
--- intdoc.texi	15 Sep 2002 21:59:33 -0000	1.22
+++ intdoc.texi	23 Sep 2002 10:33:11 -0000
@@ -2226,7 +2226,7 @@
 
 Sets the current working directory to be @var{Dir}.
 If the @var{Status} argument is supplied, it contains 0
-on success or a non-zero error code otherwise upon return.
+on success or a nonzero error code otherwise upon return.
 See @code{chdir(3)}.
 
 @emph{Caution:} Using this routine during I/O to a unit connected with a
@@ -2265,7 +2265,7 @@
 Description:
 
 Sets the current working directory to be @var{Dir}.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 See @code{chdir(3)}.
 
 @emph{Caution:} Using this routine during I/O to a unit connected with a
@@ -2315,7 +2315,7 @@
 character.
 
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 
 Note that this currently works
 by actually invoking @code{/bin/chmod} (or the @code{chmod} found when
@@ -2365,7 +2365,7 @@
 Currently, @var{Name} must not contain the single quote
 character.
 
-Returns 0 on success or a non-zero error code otherwise.
+Returns 0 on success or a nonzero error code otherwise.
 
 Note that this currently works
 by actually invoking @code{/bin/chmod} (or the @code{chmod} found when
@@ -5067,7 +5067,7 @@
 If an element is not relevant, it is returned as 0.
 
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
 only a function, not as a subroutine, or do not support the
@@ -5152,7 +5152,7 @@
 Not all these elements are relevant on all systems.
 If an element is not relevant, it is returned as 0.
 
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 
 For information on other intrinsics with the same name:
 @xref{FStat Intrinsic (subroutine)}.
@@ -5292,7 +5292,7 @@
 
 Places the current working directory in @var{Name}.
 If the @var{Status} argument is supplied, it contains 0
-success or a non-zero error code upon return
+success or a nonzero error code upon return
 (@code{ENOSYS} if the system does not provide @code{getcwd(3)}
 or @code{getwd(3)}).
 
@@ -5327,7 +5327,7 @@
 
 Places the current working directory in @var{Name}.
 Returns 0 on
-success, otherwise a non-zero error code
+success, otherwise a nonzero error code
 (@code{ENOSYS} if the system does not provide @code{getcwd(3)}
 or @code{getwd(3)}).
 
@@ -5537,7 +5537,7 @@
 Fills @var{Name} with the system's host name returned by
 @code{gethostname(2)}.
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return
+0 on success or a nonzero error code upon return
 (@code{ENOSYS} if the system does not provide @code{gethostname(2)}).
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -5575,7 +5575,7 @@
 Description:
 
 Fills @var{Name} with the system's host name returned by
-@code{gethostname(2)}, returning 0 on success or a non-zero error code
+@code{gethostname(2)}, returning 0 on success or a nonzero error code
 (@code{ENOSYS} if the system does not provide @code{gethostname(2)}).
 
 On some systems (specifically SCO) it might be necessary to link the
@@ -7107,7 +7107,7 @@
 
 Sends the signal specified by @var{Signal} to the process @var{Pid}.
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 See @code{kill(2)}.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -7145,7 +7145,7 @@
 Description:
 
 Sends the signal specified by @var{Signal} to the process @var{Pid}.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 See @code{kill(2)}.
 
 Due to the side effects performed by this intrinsic, the function
@@ -7377,7 +7377,7 @@
 the names in @var{Path1} and @var{Path2}---otherwise,
 trailing blanks in @var{Path1} and @var{Path2} are ignored.
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 See @code{link(2)}.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -7418,7 +7418,7 @@
 A null character (@samp{CHAR(0)}) marks the end of
 the names in @var{Path1} and @var{Path2}---otherwise,
 trailing blanks in @var{Path1} and @var{Path2} are ignored.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 See @code{link(2)}.
 
 Due to the side effects performed by this intrinsic, the function
@@ -7802,7 +7802,7 @@
 If an element is not relevant, it is returned as 0.
 
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return
+0 on success or a nonzero error code upon return
 (@code{ENOSYS} if the system does not provide @code{lstat(2)}).
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -7893,7 +7893,7 @@
 Not all these elements are relevant on all systems.
 If an element is not relevant, it is returned as 0.
 
-Returns 0 on success or a non-zero error code
+Returns 0 on success or a nonzero error code
 (@code{ENOSYS} if the system does not provide @code{lstat(2)}).
 
 For information on other intrinsics with the same name:
@@ -9085,7 +9085,7 @@
 trailing blanks in @var{Path1} and @var{Path2} are ignored.
 See @code{rename(2)}.
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
 only a function, not as a subroutine, or do not support the
@@ -9126,7 +9126,7 @@
 the names in @var{Path1} and @var{Path2}---otherwise,
 trailing blanks in @var{Path1} and @var{Path2} are ignored.
 See @code{rename(2)}.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 
 Due to the side effects performed by this intrinsic, the function
 form is not recommended.
@@ -9931,7 +9931,7 @@
 If an element is not relevant, it is returned as 0.
 
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
 only a function, not as a subroutine, or do not support the
@@ -10018,7 +10018,7 @@
 Not all these elements are relevant on all systems.
 If an element is not relevant, it is returned as 0.
 
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 
 For information on other intrinsics with the same name:
 @xref{Stat Intrinsic (subroutine)}.
@@ -10067,7 +10067,7 @@
 the names in @var{Path1} and @var{Path2}---otherwise,
 trailing blanks in @var{Path1} and @var{Path2} are ignored.
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return
+0 on success or a nonzero error code upon return
 (@code{ENOSYS} if the system does not provide @code{symlink(2)}).
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -10108,7 +10108,7 @@
 A null character (@samp{CHAR(0)}) marks the end of
 the names in @var{Path1} and @var{Path2}---otherwise,
 trailing blanks in @var{Path1} and @var{Path2} are ignored.
-Returns 0 on success or a non-zero error code
+Returns 0 on success or a nonzero error code
 (@code{ENOSYS} if the system does not provide @code{symlink(2)}).
 
 Due to the side effects performed by this intrinsic, the function
@@ -10657,7 +10657,7 @@
 the name in @var{File}---otherwise,
 trailing blanks in @var{File} are ignored.
 If the @var{Status} argument is supplied, it contains
-0 on success or a non-zero error code upon return.
+0 on success or a nonzero error code upon return.
 See @code{unlink(2)}.
 
 Some non-GNU implementations of Fortran provide this intrinsic as
@@ -10695,7 +10695,7 @@
 A null character (@samp{CHAR(0)}) marks the end of
 the name in @var{File}---otherwise,
 trailing blanks in @var{File} are ignored.
-Returns 0 on success or a non-zero error code.
+Returns 0 on success or a nonzero error code.
 See @code{unlink(2)}.
 
 Due to the side effects performed by this intrinsic, the function
Index: invoke.texi
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/invoke.texi,v
retrieving revision 1.15
diff -u -r1.15 invoke.texi
--- invoke.texi	31 Aug 2002 14:40:23 -0000	1.15
+++ invoke.texi	23 Sep 2002 10:33:14 -0000
@@ -389,7 +389,7 @@
 is specified as a command-line option for @command{g77} or @command{gcc}
 and when the resulting commands compile Fortran source files.
 
-In GCC 3.1, this is changed back to the behaviour @command{gcc} displays
+In GCC 3.1, this is changed back to the behavior @command{gcc} displays
 for @samp{.c} files.
 
 @cindex -fset-g77-defaults option
Index: news.texi
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/news.texi,v
retrieving revision 1.88
diff -u -r1.88 news.texi
--- news.texi	9 Sep 2002 20:37:09 -0000	1.88
+++ news.texi	23 Sep 2002 10:33:16 -0000
@@ -2315,7 +2315,7 @@
 
 @item
 Change code generation for list-directed I/O so it allows
-for new versions of @code{libf2c} that might return non-zero
+for new versions of @code{libf2c} that might return nonzero
 status codes for some operations previously assumed to always
 return zero.
 


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: com.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/f/com.c,v
retrieving revision 1.179
diff -u -r1.179 com.c
--- com.c	16 Sep 2002 18:33:22 -0000	1.179
+++ com.c	23 Sep 2002 10:32:48 -0000
@@ -821,7 +821,7 @@
    `item' is NULL_TREE, or the transformed pointer to the array.
    `expr' is the original opARRAYREF expression, which is transformed
      if `item' is NULL_TREE.
-   `want_ptr' is non-zero if a pointer to the element, instead of
+   `want_ptr' is nonzero if a pointer to the element, instead of
      the element itself, is to be returned.  */
 
 static tree
@@ -14758,12 +14758,12 @@
     case ABS_EXPR:
     case FLOAT_EXPR:
     case FFS_EXPR:
       /* These don't change whether an object is non-zero or zero.  */
       return ffe_truthvalue_conversion (TREE_OPERAND (expr, 0));
 
     case LROTATE_EXPR:
     case RROTATE_EXPR:
       /* These don't change whether an object is zero or non-zero, but
 	 we can't ignore them if their second arg has side-effects.  */
       if (TREE_SIDE_EFFECTS (TREE_OPERAND (expr, 1)))
 	return build (COMPOUND_EXPR, integer_type_node, TREE_OPERAND (expr, 1),
@@ -15029,7 +15029,7 @@
     char *fname;
     /* Mapping of file names for this directory.  */
     struct file_name_map *name_map;
     /* Non-zero if name_map is valid.  */
     int got_name_map;
   };
 
@@ -14758,12 +14758,12 @@
     case FLOAT_EXPR:
     case FFS_EXPR:
-      /* These don't change whether an object is non-zero or zero.  */
+      /* These don't change whether an object is nonzero or zero.  */
       return ffe_truthvalue_conversion (TREE_OPERAND (expr, 0));
 
@@ -14758,12 +14758,12 @@
     case LROTATE_EXPR:
     case RROTATE_EXPR:
-      /* These don't change whether an object is zero or non-zero, but
+      /* These don't change whether an object is zero or nonzero, but
 	 we can't ignore them if their second arg has side-effects.  */
       if (TREE_SIDE_EFFECTS (TREE_OPERAND (expr, 1)))
@@ -15029,7 +15029,7 @@
     /* Mapping of file names for this directory.  */
     struct file_name_map *name_map;
-    /* Non-zero if name_map is valid.  */
+    /* Nonzero if name_map is valid.  */
     int got_name_map;
   };